@@ -4,7 +4,7 @@
 
 #pragma once
 
-#include "converters.h"
+#include <Quotient/converters.h>
 
 namespace Quotient {
 /// Used by clients to discover identity server information.
@@ -21,7 +21,7 @@ struct JsonObjectConverter<IdentityServerInformation> {
     }
     static void fillFrom(const QJsonObject& jo, IdentityServerInformation& pod)
     {
-        fromJson(jo.value("base_url"_ls), pod.baseUrl);
+        fillFromJson(jo.value("base_url"_ls), pod.baseUrl);
     }
 };
 
